@@ -1,5 +1,26 @@
 <?php
 /**
+ * Copyright 2008-2017 Horde LLC (http://www.horde.org/)
+ *
+ * See the enclosed file LICENSE for license information (LGPL). If you
+ * did not receive this file, see http://www.horde.org/licenses/lgpl21.
+ *
+ * @author   Chuck Hagenbuch <chuck@horde.org>
+ * @author   Jan Schneider <jan@horde.org>
+ * @category Horde
+ * @license  http://www.horde.org/licenses/lgpl21 LGPL
+ * @package  Date_Parser
+ */
+
+/**
+ *
+ *
+ * @author    Chuck Hagenbuch <chuck@horde.org>
+ * @author    Jan Schneider <jan@horde.org>
+ * @category  Horde
+ * @copyright 2008-2017 Horde LLC
+ * @license   http://www.horde.org/licenses/lgpl21 LGPL
+ * @package   Date_Parser
  */
 class Horde_Date_Parser_Locale_Pt extends Horde_Date_Parser_Locale_Base
 {
@@ -100,7 +121,9 @@ class Horde_Date_Parser_Locale_Pt extends Horde_Date_Parser_Locale_Base
         }
 
         // strip any non-tagged tokens
-        $taggedTokens = array_values(array_filter($tokens, create_function('$t', 'return $t->tagged();')));
+        $taggedTokens = array_values(array_filter(
+            $tokens, function ($t) { return $t->tagged(); }
+        ));
 
         // Remove tokens we know we don't want - for example, if the first
         // token is a separator, drop it.
